/*
 * File:   DisplayManager.cpp
 * Author: Bob Alexander
 *
 * Created on November 20, 2014, 5:10 PM
 */

#include "Common.h"
#include "app.h"
#include "LEDDisplay.h"
#include "DisplayManager.h"

static void HiPriorityTextTimeout(uintptr_t context, uint32_t currTick);

static char m_hiPriorityText[13], m_text[13] = "    ";
SYS_TMR_HANDLE m_hiPriorityTextCallback = SYS_TMR_HANDLE_INVALID;

struct CharIndicatorInfo
{
    int charIndex;
    SYS_TMR_HANDLE timer;
};

void DisplayManager_Initialize()
{
    LEDDisplay_Initialize();
    LEDDisplay_SetText(m_text);
}

static void SetHiPriorityText(const char *text, uint16_t timeoutMs)
{
    if (m_hiPriorityTextCallback != SYS_TMR_HANDLE_INVALID)
    {
        SYS_TMR_CallbackStop(m_hiPriorityTextCallback);
        m_hiPriorityTextCallback = SYS_TMR_HANDLE_INVALID;
    }
    strncpy(m_hiPriorityText, text, countof(m_hiPriorityText) - 1);
    if (timeoutMs != DISPLAY_TIMEOUT_INFINITE)
    {
        do
        {
            m_hiPriorityTextCallback = SYS_TMR_CallbackSingle(timeoutMs, 0, &HiPriorityTextTimeout);
        } while (m_hiPriorityTextCallback == SYS_TMR_HANDLE_INVALID);
    }
    LEDDisplay_SetText(m_hiPriorityText);
}

static void SetText(const char *text)
{
    strncpy(m_text, text, countof(m_text) - 1);
    if (m_hiPriorityText[0] == '\0')
        LEDDisplay_SetText(m_text);
}

static void HiPriorityTextTimeout(uintptr_t context, uint32_t currTick)
{
    UNUSED(context);
    UNUSED(currTick);
    memset(m_hiPriorityText, 0, sizeof(m_hiPriorityText));
    LEDDisplay_SetText(m_text);
    m_hiPriorityTextCallback = SYS_TMR_HANDLE_INVALID;
}

static void CharIndicatorTimeout(uintptr_t context, uint32_t currTick)
{
    char newText[countof(m_text)];
    struct CharIndicatorInfo *info = (struct CharIndicatorInfo *) context;
    UNUSED(currTick);
    strcpy(newText, m_text);
    newText[info->charIndex] = ' ';
    SetText(newText);
    info->timer = SYS_TMR_HANDLE_INVALID;
}

static void ToggleCharIndicator(struct CharIndicatorInfo *info, char ch)
{
    char newText[countof(m_text)];
    if (info->timer != SYS_TMR_HANDLE_INVALID)
    {
        SYS_TMR_CallbackStop(info->timer);
    }
    strcpy(newText, m_text);
    if (ch == ' ')
        newText[info->charIndex] = '_';
    else if (ch > ' ' && ch < '\x7f')
        newText[info->charIndex] = ch;
    else
        newText[info->charIndex] = '?';
    do
    {
        info->timer = SYS_TMR_CallbackSingle(250, (uintptr_t) info, &CharIndicatorTimeout);
    } while (info->timer == SYS_TMR_HANDLE_INVALID);
    SetText(newText);
}

void DisplayManager_BTCharReceived(char ch)
{
    static struct CharIndicatorInfo info = {3, SYS_TMR_HANDLE_INVALID};
    ToggleCharIndicator(&info, ch);
}

void DisplayManager_SUTCharReceived(char ch)
{
    static struct CharIndicatorInfo info = {0, SYS_TMR_HANDLE_INVALID};
    ToggleCharIndicator(&info, ch);
}

void DisplayManager_ShowBaudRate(int baud, size_t timeout)
{
    char buf[10] = " ";
    if (baud == DISPLAY_AUTO)
        strcpy(buf, "Auto");
    else if (baud == DISPLAY_ERR)
        strcpy(buf, "Err ");
    else if (baud < 1000)
        itoa(buf + 1, baud, 10);
    else if (baud < 10000)
        itoa(buf, baud, 10);
    else
    {
        char *dest;
        if (baud < 100000)
            dest = buf + 1;
        else
            dest = buf;
        size_t len;
        itoa(dest, baud / 1000, 10);
        len = strlen(buf);
        buf[len++] = '.';
        baud = baud % 1000 / 100;
        itoa(buf + len, baud, 10);
    }
    SetHiPriorityText(buf, timeout);
}
