/* 
 * File:   LEDDisplay.cpp
 * Author: Bob Alexander
 * 
 * Created on November 20, 2014, 5:10 PM
 */

#include "Common.h"
#include "app.h"
#include "LEDDisplay.h"
#include <string.h>
#include <ctype.h>

static void TimerCallback(uintptr_t context, uint32_t currTick);

char m_text[12];
uint8_t m_encoding[4];
uint8_t m_digit;

void LEDDisplay_Initialize()
{
    m_digit = 0;
    memset(m_text, 0, sizeof(m_text));
    memset(m_encoding, 0, sizeof(m_encoding));
    SYS_PORTS_Set(PORTS_ID_0, PORT_CHANNEL_A, 0xf, 0xf);

    // Get a callback to refresh the LEDs. We want to refresh at 60 Hz and there are 4 digits
    while (SYS_TMR_CallbackPeriodic(1000 / 60 / 4, 0, &TimerCallback) == SYS_TMR_HANDLE_INVALID)
    {
    }
}

void LEDDisplay_SetText(const char *text)
{
    strncpy(m_text, text, countof(m_text));

    static const uint8_t sevenSegmentEncoding[] =
    {
        0b00000000, // space
        0b10000110, // !
        0b00100010, // "
        0b01111110, // #
        0b01010011, // $ => ?
        0b01010011, // % => ?
        0b01010011, // & => ?
        0b00100000, // '
        0b00111001, // (
        0b00001111, // )
        0b01010011, // * => ?
        0b01010011, // + => ?
        0b00001100, // ,
        0b01000000, // -
        0b10000000, // .
        0b01010010, // /
        0b00111111, // 0
        0b00000110, // 1
        0b01011011, // 2
        0b01001111, // 3
        0b01100110, // 4
        0b01101101, // 5
        0b01111101, // 6
        0b00000111, // 7
        0b01111111, // 8
        0b01100111, // 9
        0b01010011, // : => ?
        0b01010011, // ; => ?
        0b01010011, // < => ?
        0b01001000, // =
        0b01010011, // > => ?
        0b01010011, // ?
        0b01010011, // @ => ?
        0b01110111, // A
        0b01111100, // b
        0b00111001, // C
        0b01011110, // d
        0b01111001, // E
        0b01110001, // F
        0b00111101, // G
        0b01110110, // H
        0b00110000, // I
        0b00011110, // J
        0b01010011, // K => ?
        0b00111000, // L
        0b01010011, // M => ?
        0b01010100, // n
        0b00111111, // O
        0b01110011, // P
        0b01100111, // q
        0b01010000, // r
        0b01101101, // S
        0b01111000, // t
        0b00111110, // U
        0b01010011, // V => ?
        0b01010011, // W => ?
        0b01010011, // X => ?
        0b01101110, // y
        0b01011011, // Z
        0b00111001, // [
        0b01100100, // backslash
        0b00001111, // ]
        0b00100011, // ^
        0b00001000, // _
        0b00000010, // `
        0b01110111, // A
        0b01111100, // b
        0b01011000, // c
        0b01011110, // d
        0b01111001, // E
        0b01110001, // F
        0b01101111, // g
        0b01110100, // h
        0b00010000, // i
        0b00011110, // J
        0b01010011, // k => ?
        0b00110000, // l
        0b01010011, // m => ?
        0b01010100, // n
        0b01011100, // o
        0b01110011, // p
        0b01100111, // q
        0b01010000, // r
        0b01101101, // S
        0b01111000, // t
        0b00011100, // u
        0b01010011, // v => ?
        0b01010011, // w => ?
        0b01010011, // x => ?
        0b01101110, // y
        0b01011011, // Z
        0b01010011, // { => ?
        0b00110000, // |
        0b01010011, // } => ?
        0b01000000, // ~
        0b01010011, // 0x7f => ?
    };

    SYS_INT_Disable();
    memset(m_encoding, 0, sizeof(m_encoding));
    uint8_t *d = m_encoding;
    const char *s = m_text;
    for (; *s && s < m_text + countof(m_text) && d < m_encoding + countof(m_encoding); ++s)
    {
        // If the character is a backspace (used to OR LED segments on top of each other)
        if (*s == '\x8' && d > m_encoding)
            --d;
        if (*s >= ' ' && *s <= '\x7f')
        {
            if (*s == '.' && d > m_encoding)
                *(d - 1) |= sevenSegmentEncoding['.' - ' '];
            else
                *d++ |= sevenSegmentEncoding[*s - ' '];
        }
    }
    SYS_INT_Enable();
}

void TimerCallback(uintptr_t context, uint32_t currTick)
{
    context;
    currTick;
    
    // Turn off all the LED digits by setting the cathodes high
    SYS_PORTS_Set(PORTS_ID_0, PORT_CHANNEL_A, 0xf, 0xf);

    // Output the encoding for the character
    SYS_PORTS_Write(PORTS_ID_0, PORT_CHANNEL_B, m_encoding[m_digit]);

    // Enable the specific LED digit by setting its cathode low
    SYS_PORTS_Clear(PORTS_ID_0, PORT_CHANNEL_A, 1 << m_digit);

    if (++m_digit > countof(m_encoding))
        m_digit = 0;
}
